@@ -3,7 +3,10 @@ from typing import Any
 
 import jwt
 
-def create_identity_token(user_id: int, secret: str, expire_after_minutes: int = 10) -> str:
+
+def create_identity_token(
+    user_id: int, secret: str, expire_after_minutes: int = 10
+) -> str:
     now = datetime.utcnow()
 
     payload = {
@@ -16,3 +19,17 @@ def create_identity_token(user_id: int, secret: str, expire_after_minutes: int =
 
 def decode_pastaporto(token: str, secret: str) -> dict[str, Any]:
     return jwt.decode(token, str(secret), algorithms=["HS256"])
+
+
+def decode_service_to_service_token(
+    token: str, secret: str, *, issuer: str, audience: str
+):
+    return jwt.decode(
+        token,
+        secret,
+        verify=True,
+        audience=audience,
+        issuer=issuer,
+        algorithms=["HS256"],
+        options={"require": ["exp", "iss", "aud"]},
+    )
